@@ -3,8 +3,10 @@ import operator
 
 from django.contrib.auth.models import User
 from django.db import models
-from django.utils.translation import ugettext as _
 from django.utils.text import Truncator, slugify
+from django.utils.translation import ugettext as _
+
+from . import settings
 
 
 class TimestampedModel(models.Model):
@@ -16,20 +18,15 @@ class TimestampedModel(models.Model):
 
 
 class CategoryManager(models.Manager):
-    def children_of(self, category, categories=None, acc=None):
-        if acc is None:
-            acc = []
-
+    def children_of(self, category, categories=None):
         if categories is None:
-            categories = self.all()
+            categories = list(self.all())
 
         children = filter(lambda c: c.parent == category, categories)
         for child in children:
-            acc.extend(self.children_of(child, categories, acc))
+            children.extend(self.children_of(child, categories))
 
-        acc.extend(children)
-
-        return acc
+        return children
 
 
 class Category(models.Model):
@@ -175,3 +172,10 @@ class Post(TimestampedModel):
             return self.summary
         else:
             return Truncator(self.body).words(30)
+
+    @property
+    def rendered(self):
+        if settings.MARKUP_RENDERER:
+            return settings.MARKUP_RENDERER(self.body)
+        else:
+            return self.body
